# Changelog

## 0.0.1-alpha.1 (2025-02-25)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/ShortGenius/shortgenius-sdk-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/ShortGenius/shortgenius-sdk-python/issues/1)) ([d3c8bc1](https://github.com/ShortGenius/shortgenius-sdk-python/commit/d3c8bc19fe069344ce7bbbdfd8ecc6ef56ce19d7))
* update SDK settings ([#3](https://github.com/ShortGenius/shortgenius-sdk-python/issues/3)) ([fdd8c1f](https://github.com/ShortGenius/shortgenius-sdk-python/commit/fdd8c1f4e52329eefca1037e67df809fe4c169fe))
